@@ -22,7 +22,17 @@ key_words <- function(cf = NULL, gcmd = NULL, url = eurl(), ...){
   args <- rc(list(cf = cf, gcmd = gcmd))
   cli <- crul::HttpClient$new(url = file.path(pu(url), 'convert/keywords.txt'), 
     opts = list(...))
-  res <- cli$get(query = args)
+  # res <- cli$get(query = args)
+  response <- tryCatch(
+    {
+      res <- cli$get(query = args)  # Attempt to fetch
+    },
+    error = function(e) {
+      message("Curl request failed on finding keyword: ", e$message)
+      quit(save = "no", status = 1)  # Gracefully exit R session
+    }
+  )
+  
   res$raise_for_status()
   res$parse("UTF-8")
 }
